This is a selection of functions providing loading functionalities for files created with ARYELLE series spectrometers from [LTB Lasertechnik Berlin GmbH](https://www.ltb-berlin.de/) and the Sophi software.

Documentation of the formats can be found on the corresponding [gitlab-page](https://gitlab.com/ltb_berlin/ltb_files/-/wikis/home).

Issues can be reported online in the projects [issue-tracker](https://gitlab.com/ltb_berlin/ltb_files).

Users of MATLAB can find instructions [here](https://gitlab.com/ltb_berlin/ltb_files/-/wikis/matlab).
